/// <reference types="hoist-non-react-statics" />
import React from 'react';
import _ from 'lodash';
import { ThemeProps } from '../theme';
import { LocaleProps } from '../locale';
export interface HistoryRecord {
    /** 历史记录值 */
    value: string;
    /** 历史记录生成的unix时间戳 */
    timestamp?: number;
}
export interface SearchHistoryOptions {
    /** 是否开启历史记录 */
    enable: boolean;
    /** 本地存储历史记录的key */
    key?: string;
    /** 历史记录数量上限 */
    limit?: number;
    /** 历史记录下拉面板CSS类名 */
    dropdownClassName?: string;
}
export interface SearchBoxProps extends ThemeProps, LocaleProps {
    name?: string;
    disabled?: boolean;
    mini?: boolean;
    enhance?: boolean;
    clearable?: boolean;
    searchImediately?: boolean;
    onChange?: (text: string) => void;
    placeholder?: string;
    defaultValue?: string;
    value?: string;
    active?: boolean;
    defaultActive?: boolean;
    onActiveChange?: (active: boolean) => void;
    onSearch?: (value: string) => void;
    onCancel?: () => void;
    /** 历史记录配置 */
    history?: SearchHistoryOptions;
}
export interface SearchBoxState {
    isFocused: boolean;
    isHistoryOpened: boolean;
    inputValue: string;
    historyRecords: HistoryRecord[];
}
export declare class SearchBox extends React.Component<SearchBoxProps, SearchBoxState> {
    inputRef: React.RefObject<HTMLInputElement>;
    static defaultProps: {
        mini: boolean;
        enhance: boolean;
        clearable: boolean;
        searchImediately: boolean;
        history: Required<SearchHistoryOptions>;
    };
    state: {
        isHistoryOpened: boolean;
        isFocused: boolean;
        inputValue: string;
        historyRecords: any[];
    };
    lazyEmitSearch: _.DebouncedFunc<() => void>;
    componentDidUpdate(prevProps: SearchBoxProps): void;
    componentWillUnmount(): void;
    handleActive(): void;
    handleCancel(): void;
    handleChange(e: React.ChangeEvent<HTMLInputElement>): void;
    handleSearch(): void;
    handleKeyDown(e: React.KeyboardEvent<any>): void;
    handleClear(): void;
    handleFocus(): void;
    handleBlur(e: React.FocusEvent<HTMLInputElement>): void;
    handleHistoryRecordSelect(record: HistoryRecord): void;
    /** 获取历史搜索配置 */
    getHistoryOptions(): Required<SearchHistoryOptions>;
    /** 获取历史记录 */
    getHistoryRecords(): any[];
    /** 清空历史记录 */
    clearHistoryRecords(): HistoryRecord[];
    /** 删除一条历史记录 */
    removeHistoryRecord(record: HistoryRecord): HistoryRecord[];
    /** 新增一条历史记录 */
    insertHistoryRecord(value: string): HistoryRecord[];
    renderInput(isHistoryMode?: boolean): JSX.Element;
    renderTag(item: HistoryRecord, index: number): JSX.Element;
    renderHitoryMode(): JSX.Element;
    render(): JSX.Element;
}
declare const _default: {
    new (props: Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
        mini: boolean;
        enhance: boolean;
        clearable: boolean;
        searchImediately: boolean;
        history: Required<SearchHistoryOptions>;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }, keyof ThemeProps> & import("../theme").ThemeOutterProps): {
        ref: any;
        childRef(ref: any): void;
        getWrappedInstance(): any;
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<{
        new (props: Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }): {
            ref: any;
            childRef(ref: any): void;
            getWrappedInstance(): any;
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<typeof SearchBox>;
    } & import("hoist-non-react-statics").NonReactStatics<typeof SearchBox, {}> & {
        ComposedComponent: typeof SearchBox;
    }>;
} & import("hoist-non-react-statics").NonReactStatics<{
    new (props: Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
        mini: boolean;
        enhance: boolean;
        clearable: boolean;
        searchImediately: boolean;
        history: Required<SearchHistoryOptions>;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }): {
        ref: any;
        childRef(ref: any): void;
        getWrappedInstance(): any;
        render(): JSX.Element;
        context: any;
        setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<typeof SearchBox>;
} & import("hoist-non-react-statics").NonReactStatics<typeof SearchBox, {}> & {
    ComposedComponent: typeof SearchBox;
}, {}> & {
    ComposedComponent: {
        new (props: Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
            mini: boolean;
            enhance: boolean;
            clearable: boolean;
            searchImediately: boolean;
            history: Required<SearchHistoryOptions>;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }): {
            ref: any;
            childRef(ref: any): void;
            getWrappedInstance(): any;
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "defaultValue" | "disabled" | "onCancel" | "name" | "active" | "placeholder" | "onChange" | "defaultActive" | "onActiveChange" | "onSearch"> & Partial<Pick<Omit<SearchBoxProps, keyof LocaleProps>, "clearable" | "enhance" | "mini" | "searchImediately" | "history">> & Partial<Pick<{
                mini: boolean;
                enhance: boolean;
                clearable: boolean;
                searchImediately: boolean;
                history: Required<SearchHistoryOptions>;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<typeof SearchBox>;
    } & import("hoist-non-react-statics").NonReactStatics<typeof SearchBox, {}> & {
        ComposedComponent: typeof SearchBox;
    };
};
export default _default;
